Index: /extensions/ConcoursPhoto/admin/admin.php
===================================================================
--- /extensions/ConcoursPhoto/admin/admin.php	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/admin.php	(revision 4428)
@@ -35,10 +35,11 @@
                $my_base_url.'&amp;tab=params');
 
-$tabsheet->add('audit',
+/*$tabsheet->add('audit',
                l10n('concours_audit'),
                $my_base_url.'&amp;tab=audit');
-
+*/
 $tabsheet->select($page['tab']);
 $tabsheet->assign();
+
 
 
Index: /extensions/ConcoursPhoto/admin/audit.php
===================================================================
--- /extensions/ConcoursPhoto/admin/audit.php	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/audit.php	(revision 4428)
@@ -11,4 +11,12 @@
 global $template;
 
+
+if (isset($_POST['user_list']))
+    $user_id = $_POST['user_list'];
+else 
+    $user_id = 0;
+    
+//echo "USER_ID=".$user_id;
+   
 // Get the concours id if present
 if (isset($_GET['concours']))
@@ -18,4 +26,34 @@
 	$concours = new Concours($concours_id);
 
+    // Get group authorized to participate 
+    $users = array();     // contain {id;username} or each 
+    $groups = $concours->concours_infos['groups'];
+    $query = 'SELECT user_id, username FROM ' . USER_GROUP_TABLE 
+    .' INNER JOIN ' . USERS_TABLE .' ON id = user_id'
+    .($groups != NULL ? ' WHERE group_id = '.$groups : '')
+    .' ORDER BY username ASC'
+    .';';
+if ($concours->debug)		echo $query."\n";
+    $result = pwg_query($query);
+    while ($row = mysql_fetch_assoc($result))
+    {
+      array_push($users, $row);
+    }       
+
+    // Add user list
+    $template->append('user_list',
+        array(	'ID' => '0',
+                'NAME' => l10n('all_users'),
+                'SELECTED' => ($user_id == 0 ? 'selected' : '')));
+
+    foreach ( $users as $userid ) //on parcours le tableau 
+    {
+        $template->append('user_list',
+            array(	'ID' => $userid['user_id'],
+                    'NAME' => $userid['username'],
+                    'SELECTED' => ($user_id == $userid['user_id'] ? 'selected' : '')));
+    }
+
+    
     // Send concours info to template
     $template->assign( 'CONCOURS', array(
@@ -147,8 +185,8 @@
 		$user_note = array();
 		$globalnote = 0;
-		if (isset($_GET['user_id']))	// for user 
-		{
-			$globalnote = $concours->get_img_globalnote_user($row['id'], $concours_id, $_GET['user_id']);
-			$user_note = $concours->get_img_note_user($row['id'], $concours_id, $_GET['user_id']);
+		if ($user_id != 0)	// for user 
+		{
+			$globalnote = $concours->get_img_globalnote_user($row['id'], $concours_id, $user_id);
+			$user_note = $concours->get_img_note_user($row['id'], $concours_id, $user_id);
 		}
 		else	// global
Index: /extensions/ConcoursPhoto/admin/params.php
===================================================================
--- /extensions/ConcoursPhoto/admin/params.php	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/params.php	(revision 4428)
@@ -15,4 +15,5 @@
   $concours->my_config['mask_author'] = isset($_POST['mask_author']);
   $concours->my_config['thumb_note'] = isset($_POST['thumb_note']);
+  $concours->my_config['mask_exif'] = isset($_POST['mask_exif']);
 
   $concours->save_config();
@@ -30,4 +31,5 @@
     'MASK_AUTHOR' 			=> ($concours->my_config['mask_author'] ? 'checked="checked"' : ''),
     'THUMB_NOTE' 			=> ($concours->my_config['thumb_note'] ? 'checked="checked"' : ''),
+    'MASK_EXIF' 			=> ($concours->my_config['mask_exif'] ? 'checked="checked"' : ''),
 			));
 
Index: /extensions/ConcoursPhoto/admin/template/add_concours.tpl
===================================================================
--- /extensions/ConcoursPhoto/admin/template/add_concours.tpl	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/template/add_concours.tpl	(revision 4428)
@@ -182,18 +182,18 @@
 <fieldset>
 	<legend>{'concours_criterias'|@translate}</legend>
-	 <table border="1">
-		<tr>
-			<td><b>{'concours_id'|@translate}</b></td>
-			<td><b>{'concours_name'|@translate}</b></td>
-			<td width="50%"><b>{'concours_descr'|@translate}</b></td>
-			<td><b>{'concours_min_value'|@translate}</b></td>
-			<td><b>{'concours_max_value'|@translate}</b></td>
-			<td><b>{'concours_coef'|@translate}</b></td>
+     <table class="table2 littlefont" id="criteria_list" border="1">
+        <tr class="throw">
+			<th><b>{'concours_id2'|@translate}</b></td>
+			<th><b>{'concours_name'|@translate}</b></td>
+			<th><b>{'concours_descr'|@translate}</b></td>
+			<th><b>{'concours_min_value'|@translate}</b></td>
+			<th><b>{'concours_max_value'|@translate}</b></td>
+			<th><b>{'concours_coef'|@translate}</b></td>
 			{if $action != 'edit'}
-			<td width="10%"><b>{'concours_actions'|@translate}</b></td>
+			<th colspan="3"><b>{'concours_actions'|@translate}</b></td>
 			{/if}
 		</tr>
 	 {foreach from=$concours_criteria item=concours_criteria}
-		<tr>
+        <tr class="TableRow" style="cursor:pointer;">
 			<td>{$concours_criteria.id}</td>		
 			<td>
@@ -214,13 +214,17 @@
 			{if $action != 'edit'}
 			<td>
+				{if $concours_criteria.level == 1}
+					<a href="{$concours_criteria.U_ADD}" title="{'subcriteria_add'|@translate}" ><img src="{$IMG_URL}add.png" class="button" alt="{'subcriteria_add'|@translate}" /></a>
+				{/if}
+			</td>
+			<td>
 				{if isset($concours_criteria.U_EDIT)}
 					<a href="{$concours_criteria.U_EDIT}" title="{'criteria_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'criteria_edit'|@translate}"/></a>
 					&nbsp;
 				{/if}
+			</td>
+			<td>
 				{if isset($concours_criteria.U_DELETE)}
 					<a href="{$concours_criteria.U_DELETE}" title="{'criteria_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/delete.png" class="button" alt="{'criteria_delete'|@translate}" /></a>
-				{/if}
-				{if $concours_criteria.level == 1}
-					<a href="{$concours_criteria.U_ADD}" title="{'subcriteria_add'|@translate}" ><img src="{$IMG_URL}add.png" class="button" alt="{'subcriteria_add'|@translate}" /></a>
 				{/if}
 			</td>
Index: /extensions/ConcoursPhoto/admin/template/audit.tpl
===================================================================
--- /extensions/ConcoursPhoto/admin/template/audit.tpl	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/template/audit.tpl	(revision 4428)
@@ -17,4 +17,13 @@
 	</table>
 	</fieldset>
+<form method="post" action="" class="properties"  ENCTYPE="multipart/form-data">
+    {'concours_username_selection'|@translate} : </b>
+        <select name="user_list">
+        {foreach from=$user_list item=user_list}
+            <option value="{$user_list.ID}" {$user_list.SELECTED}>{$user_list.NAME}</option>
+        {/foreach}
+        </select>
+    <input type="submit" name="Submit" value="{'Submit'|@translate}" />
+</form>
 	<table align="left">
 		<tr><td colspan="4"><br></td></tr>
Index: /extensions/ConcoursPhoto/admin/template/config.tpl
===================================================================
--- /extensions/ConcoursPhoto/admin/template/config.tpl	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/template/config.tpl	(revision 4428)
@@ -9,16 +9,16 @@
 	<legend>{'default_criteria'|@translate}</legend>
 
-	 <table border="1">
-		<tr>
-			<td><b>{'concours_id'|@translate}</b></td>
-			<td><b>{'concours_name'|@translate}</b></td>
-			<td width="50%"><b>{'concours_descr'|@translate}</b></td>
-			<td><b>{'concours_min_value'|@translate}</b></td>
-			<td><b>{'concours_max_value'|@translate}</b></td>
-			<td><b>{'concours_coef'|@translate}</b></td>
-			<td width="10%"><b>{'concours_actions'|@translate}</b></td>
+     <table class="table2 littlefont" id="criteria_default" border="1">
+        <tr class="throw">
+			<th><b>{'concours_id2'|@translate}</b></td>
+			<th><b>{'concours_name'|@translate}</b></td>
+			<th><b>{'concours_descr'|@translate}</b></td>
+			<th><b>{'concours_min_value'|@translate}</b></td>
+			<th><b>{'concours_max_value'|@translate}</b></td>
+			<th><b>{'concours_coef'|@translate}</b></td>
+			<th colspan="3"><b>{'concours_actions'|@translate}</b></td>
 		</tr>
 	 {foreach from=$concours_criteria item=concours_criteria}
-		<tr>
+        <tr class="TableRow" style="cursor:pointer;">
 			<td>{$concours_criteria.id}</td>		
 			<td>
@@ -38,13 +38,17 @@
 			{/if}
 			<td>
+			{if $concours_criteria.level == 1}
+				<a href="{$concours_criteria.U_ADD}" title="{'subcriteria_add'|@translate}" ><img src="{$IMG_URL}add.png" class="button" alt="{'subcriteria_add'|@translate}" /></a>
+			{/if}
+            </td>
+            <td>
 			{if isset($concours_criteria.U_EDIT)}
 				<a href="{$concours_criteria.U_EDIT}" title="{'criteria_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'criteria_edit'|@translate}"/></a>
 				&nbsp;
 			{/if}
+            </td>
+            <td>
 			{if isset($concours_criteria.U_DELETE)}
 				<a href="{$concours_criteria.U_DELETE}" title="{'criteria_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/delete.png" class="button" alt="{'criteria_delete'|@translate}" /></a>
-			{/if}
-			{if $concours_criteria.level == 1}
-				<a href="{$concours_criteria.U_ADD}" title="{'subcriteria_add'|@translate}" ><img src="{$IMG_URL}add.png" class="button" alt="{'subcriteria_add'|@translate}" /></a>
 			{/if}
 			</td>
Index: /extensions/ConcoursPhoto/admin/template/manage.tpl
===================================================================
--- /extensions/ConcoursPhoto/admin/template/manage.tpl	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/template/manage.tpl	(revision 4428)
@@ -11,16 +11,18 @@
 	<fieldset>
 		<legend>{'prepared_concours'|@translate}</legend>
-		 <table border="1">
-			<tr>
+        {if isset($prepared_concours)}
+		 <table class="table2 littlefont" id="pconcours_list" border="1">
+
+			<tr class="throw">
 				<th><b>{'concours_id2'|@translate}</b></th>
 				<th><b>{'concours_name'|@translate}</b></th>
 				<th><b>{'concours_create_date'|@translate}</b></th>
-				<th width="50%"><b>{'concours_descr'|@translate}</b></th>
+				<th><b>{'concours_descr'|@translate}</b></th>
 				<th><b>{'concours_begin_date'|@translate}</b></th>
 				<th><b>{'concours_end_date'|@translate}</b></th>
-				<th width="10%"><b>{'concours_actions'|@translate}</b></th>
+				<th colspan="4"><b>{'concours_actions'|@translate}</b></th>
 			</tr>
 		 {foreach from=$prepared_concours item=prepared_concours}
-			<tr>
+            <tr class="TableRow" style="cursor:pointer;">
 				<td>{$prepared_concours.ID}</td>		
 				<td>{$prepared_concours.NAME}</td>		
@@ -29,26 +31,30 @@
 				<td>{$prepared_concours.BEGIN_DATE}</td>		
 				<td>{$prepared_concours.END_DATE}</td>		
-				<td><a href="{$prepared_concours.U_EDIT}" title="{'concours_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'concours_edit'|@translate}"/></a>
-				&nbsp;<a href="{$prepared_concours.U_DELETE}" title="{'concours_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/category_delete.png" class="button" alt="{'concours_delete'|@translate}" /></a>
-				</td>
+				<td><a href="{$prepared_concours.U_EDIT}" title="{'concours_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'concours_edit'|@translate}"/></a></td>
+                <td><a href="{$prepared_concours.U_DELETE}" title="{'concours_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/category_delete.png" class="button" alt="{'concours_delete'|@translate}" /></a></td>
+                <td colspan="2"></td>
 			</tr>
 		{/foreach}
 		</table>
+        {else}
+        <b>{'NO_concours'|@translate}</b>
+        {/if}
 	</fieldset>
 	
 	<fieldset>
 		<legend>{'active_concours'|@translate}</legend>
-		 <table border="1">
-			<tr>
+        {if isset($active_concours)}
+		 <table class="table2 littlefont" id="aconcours_list" border="1">
+			<tr class="throw">
 				<th><b>{'concours_id2'|@translate}</b></th>
 				<th><b>{'concours_name'|@translate}</b></th>
 				<th><b>{'concours_create_date'|@translate}</b></th>
-				<th width="50%"><b>{'concours_descr'|@translate}</b></th>
+				<th><b>{'concours_descr'|@translate}</b></th>
 				<th><b>{'concours_begin_date'|@translate}</b></th>
 				<th><b>{'concours_end_date'|@translate}</b></th>
-				<th width="10%"><b>{'concours_actions'|@translate}</b></th>
+				<th colspan="4"><b>{'concours_actions'|@translate}</b></th>
 			</tr>
 		 {foreach from=$active_concours item=active_concours}
-			<tr>
+            <tr class="TableRow" style="cursor:pointer;">
 				<td>{$active_concours.ID}</td>		
 				<td><a href="{$active_concours.U_AUDIT}" title="{'concours_audit1'|@translate}">{$active_concours.NAME}</a></td>		
@@ -57,26 +63,29 @@
 				<td>{$active_concours.BEGIN_DATE}</td>		
 				<td>{$active_concours.END_DATE}</td>		
-				<td><a href="{$active_concours.U_EDIT}" title="{'concours_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'concours_edit'|@translate}"/></a>
-				&nbsp;<a href="{$active_concours.U_DELETE}" title="{'concours_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/category_delete.png" class="button" alt="{'concours_delete'|@translate}" /></a>
-				</td>
+				<td><a href="{$active_concours.U_EDIT}" title="{'concours_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'concours_edit'|@translate}"/></a></td>
+				<td><a href="{$active_concours.U_DELETE}" title="{'concours_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/category_delete.png" class="button" alt="{'concours_delete'|@translate}" /></a></td>
 			</tr>
 		{/foreach}
 		</table>
+        {else}
+        <b>{'NO_concours'|@translate}</b>
+        {/if}
 	</fieldset>
 
 	<fieldset>
 		<legend>{'closed_concours'|@translate}</legend>
-		 <table border="1">
-			<tr>
+        {if isset($closed_concours)}
+		 <table class="table2 littlefont" id="cconcours_list" border="1">
+			<tr class="throw">
 				<th><b>{'concours_id2'|@translate}</b></th>
 				<th><b>{'concours_name'|@translate}</b></th>
 				<th><b>{'concours_create_date'|@translate}</b></th>
-				<th width="50%"><b>{'concours_descr'|@translate}</b></th>
+				<th><b>{'concours_descr'|@translate}</b></th>
 				<th><b>{'concours_begin_date'|@translate}</b></th>
 				<th><b>{'concours_end_date'|@translate}</b></th>
-				<th><b>{'concours_actions'|@translate}</b></th>
+				<th colspan="4"><b>{'concours_actions'|@translate}</b></th>
 			</tr>
 		 {foreach from=$closed_concours item=closed_concours}
-			<tr>
+            <tr class="TableRow" style="cursor:pointer;">
 				<td>{$closed_concours.ID}</td>		
 				<td><a href="{$closed_concours.U_AUDIT}" title="{'concours_audit1'|@translate}">{$closed_concours.NAME}</a></td>		
@@ -85,13 +94,14 @@
 				<td>{$closed_concours.BEGIN_DATE}</td>		
 				<td>{$closed_concours.END_DATE}</td>		
-				<td><a href="{$closed_concours.U_EDIT}" title="{'concours_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'concours_edit'|@translate}"/></a>
-				&nbsp;<a href="{$closed_concours.U_DELETE}" title="{'concours_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/category_delete.png" class="button" alt="{'concours_delete'|@translate}" /></a>
-				{if $closed_concours.U_RESULT != ''}&nbsp;<a href="{$closed_concours.U_RESULT}" title="{'concours_result'|@translate}"><img src="{$IMG_URL}generate.png" class="button" alt="{'concours_result'|@translate}" /></a>{/if}
-				{if $closed_concours.U_FILE != ''}&nbsp;<a href="{$closed_concours.U_FILE}" title="{'concours_file'|@translate}"><img src="{$IMG_URL}file.png" class="button" alt="{'concours_file'|@translate}" /></a>{/if}
-				
-				</td>
+				<td><a href="{$closed_concours.U_EDIT}" title="{'concours_edit'|@translate}"><img src="{$themeconf.admin_icon_dir}/category_edit.png" class="button" alt="{'concours_edit'|@translate}"/></a></td>
+				<td><a href="{$closed_concours.U_DELETE}" title="{'concours_delete'|@translate}" onclick="return confirm('{'Are you sure?'|@translate|@escape:javascript}');"><img src="{$themeconf.admin_icon_dir}/category_delete.png" class="button" alt="{'concours_delete'|@translate}" /></a></td>
+				<td>{if $closed_concours.U_RESULT != ''}&nbsp;<a href="{$closed_concours.U_RESULT}" title="{'concours_result'|@translate}"><img src="{$IMG_URL}generate.png" class="button" alt="{'concours_result'|@translate}" /></a>{/if}</td>
+				<td>{if $closed_concours.U_FILE != ''}&nbsp;<a href="{$closed_concours.U_FILE}" title="{'concours_file'|@translate}"><img src="{$IMG_URL}file.png" class="button" alt="{'concours_file'|@translate}" /></a>{/if}</td>
 			</tr>
 		{/foreach}
 		</table>
+        {else}
+        <b>{'NO_concours'|@translate}</b>
+        {/if}
 	</fieldset>
 	
Index: /extensions/ConcoursPhoto/admin/template/params.tpl
===================================================================
--- /extensions/ConcoursPhoto/admin/template/params.tpl	(revision 4427)
+++ /extensions/ConcoursPhoto/admin/template/params.tpl	(revision 4428)
@@ -30,4 +30,10 @@
 		<TD colspan="2">
 		    <input type="checkbox" name="mask_author" {$MASK_AUTHOR}/> {'concours_mask_author'|@translate} 
+		    <br/>
+		</TD>
+	</TR>
+	<TR>
+		<TD colspan="2">
+		    <input type="checkbox" name="mask_exif" {$MASK_EXIF}/> {'concours_mask_exif'|@translate} 
 		    <br/>
 		</TD>
Index: /extensions/ConcoursPhoto/include/default_values.inc.php
===================================================================
--- /extensions/ConcoursPhoto/include/default_values.inc.php	(revision 4427)
+++ /extensions/ConcoursPhoto/include/default_values.inc.php	(revision 4428)
@@ -9,3 +9,4 @@
 $concours_default_values['mask_author'] =   true; // Mask author for prepared concours
 $concours_default_values['thumb_note'] = true; // Display global note (for user) under thumbnail
+$concours_default_values['mask_exif'] = true; // Mask exif/iptc datas during concours
 ?>
Index: /extensions/ConcoursPhoto/language/fr_FR/plugin.lang.php
===================================================================
--- /extensions/ConcoursPhoto/language/fr_FR/plugin.lang.php	(revision 4427)
+++ /extensions/ConcoursPhoto/language/fr_FR/plugin.lang.php	(revision 4428)
@@ -24,7 +24,7 @@
 $lang['concours_end_date']	 				= 'Date de fin';
 $lang['concours_criterias']	 				= 'Critères du concours';
-$lang['concours_min_value']	 				= 'Valeur minimale';
-$lang['concours_max_value']	 				= 'Valeur maximale';
-$lang['concours_coef']	 				= 'Coefficient';
+$lang['concours_min_value']	 				= 'Min.';
+$lang['concours_max_value']	 				= 'Max.';
+$lang['concours_coef']	 				= 'Coef.';
 $lang['criteria_edit']	 				= 'Editer le critère';
 $lang['criteria_delete']	 				= 'Supprimer le critère';
@@ -70,4 +70,5 @@
 
 $lang['concours_mask_author']   =  'Masquer l\'auteur pour les concours préparés non actifs';
+$lang['concours_mask_exif']   =  'Masquer les données EXIF/IPTC pour les concours préparés non actifs';
 
 $lang['thumbnail_global_note'] = 'Note concours';
@@ -90,4 +91,6 @@
 $lang['concours_audit1'] = 'Auditer le concours';
 $lang['concours_author'] = 'Auteur';
-
+$lang['NO_concours'] = 'Aucun concours';
+$lang['concours_username_selection']    = 'Sélection d\'un utilisateur';
+$lang['all_users'] = '-- Tous --';
 ?>
Index: /extensions/ConcoursPhoto/main.inc.php
===================================================================
--- /extensions/ConcoursPhoto/main.inc.php	(revision 4427)
+++ /extensions/ConcoursPhoto/main.inc.php	(revision 4428)
@@ -46,4 +46,5 @@
 
 // Add concours to picture page
+add_event_handler('loc_begin_picture', array(&$concours, 'concours_disable_exifs')); 
 add_event_handler('loc_end_picture', array(&$concours, 'display_concours_to_picture')); 
 // Add admin page
Index: /extensions/ConcoursPhoto/publish.php
===================================================================
--- /extensions/ConcoursPhoto/publish.php	(revision 4427)
+++ /extensions/ConcoursPhoto/publish.php	(revision 4428)
@@ -25,4 +25,7 @@
 $category = $concours->concours_infos['category'];
 
+if (!(isset($concours->concours_infos['method'])))
+	$concours->concours_infos['method'] = 1;
+
 $query = 'SELECT DISTINCT(img.id), img.name, img.file, img.path, img.tn_ext,img.author, 
 		  ic.category_id, cat.name AS catname, conc.note, conc.moyenne, conc.nbvotant'
@@ -31,6 +34,13 @@
 		.' INNER JOIN '.CATEGORIES_TABLE.' AS cat ON ic.category_id = cat.id'
 		.' INNER JOIN '.CONCOURS_RESULT_TABLE.' AS conc ON conc.img_id = img.id'
-		.' WHERE ic.category_id = '.$concours->concours_infos['category']
-		.' ORDER by note DESC;';
+		.' WHERE ic.category_id = '.$concours->concours_infos['category'];
+
+if ($concours->concours_infos['method'] == 1)	// total
+	$query .= ' ORDER BY note DESC';
+elseif ($concours->concours_infos['method'] == 2)	// moyenne
+	$query .= ' ORDER BY moyenne DESC';
+
+$query .=';';
+//		.' ORDER by note DESC;';
 $result = pwg_query($query);
 $rang = 1;

Index: /extensions/ConcoursPhoto/include/Concours.class.php
===================================================================
--- /extensions/ConcoursPhoto/include/Concours.class.php	(revision 4427)
+++ /extensions/ConcoursPhoto/include/Concours.class.php	(revision 4428)
@@ -755,14 +755,8 @@
 	
 
-	// Add tpl to picture.php page to display concours informations and vote
-	function display_concours_to_picture()
-	{
-		// Step1 : concours is defined to this category AND concours is open AND user is authorized to access to this category (thru group)
-		// Step1 bis : dont show concours if img_author = user_id
-		// Step 2 : Recover stored informations in db for this user
-		// Step 3 : Complete tpl information
-		// Step 4 : concat tpl
-		
-		global $page, $user, $template;
+	// Disable exif if a concours is open or prepared
+	function concours_disable_exifs()
+	{
+		global $page, $conf;
 
 		// Get user group.
@@ -771,21 +765,7 @@
 		$concours = array();
 
-		
-// DEBUG
-if ($this->debug)
-foreach ($page as $id=>$val)
-{
-	if (is_array($val))
-		foreach ($val as $id2=>$val2)
-			echo "page[".$id."][".$id2."]=".$val2."\n";
-	else
-		echo "page[".$id."]=".$val."\n";
-}
-//  END DEBUG
-
-
-	// disable author name on image which are present in a concours.
-	// check the categories where the current image is present and disable the author name
-		if ($this->my_config['mask_author'] && $this->my_config['mask_author'] == true)
+	// disable exifs  on image which are present in a concours.
+	// check the categories where the current image is present and disable the exifs
+		if (isset($page['image_id']) && isset($this->my_config['mask_exifs']) && $this->my_config['mask_exifs'] == true)
 		{
 			// Get all categories where the current image is present
@@ -816,7 +796,82 @@
         //                echo $query;
                 $result = pwg_query($query);
                 // If one or more concours are found, the author name is masked
                 if ($result && mysql_fetch_assoc($result))
+                {
+                    $conf['show_exif'] = false;
+                }
+            }
+		}
+
+	// End disable author name
+    
+    }
+
+    
+	// Add tpl to picture.php page to display concours informations and vote
+	function display_concours_to_picture()
+	{
+		// Step1 : concours is defined to this category AND concours is open AND user is authorized to access to this category (thru group)
+		// Step1 bis : dont show concours if img_author = user_id
+		// Step 2 : Recover stored informations in db for this user
+		// Step 3 : Complete tpl information
+		// Step 4 : concat tpl
+		
+		global $page, $user, $template, $conf;
+
+		// Get user group.
+		$this->get_user_groups();
+
+		$concours = array();
+
+		
+// DEBUG
+if ($this->debug)
+foreach ($page as $id=>$val)
+{
+	if (is_array($val))
+		foreach ($val as $id2=>$val2)
+			echo "page[".$id."][".$id2."]=".$val2."\n";
+	else
+		echo "page[".$id."]=".$val."\n";
+}
+//  END DEBUG
+
+	// disable author name  on image which are present in a concours.
+	// check the categories where the current image is present and disable the author name 
+		if (isset($this->my_config['mask_author']) && $this->my_config['mask_author'] == true)
+		{
+			// Get all categories where the current image is present
+			$query = '
+			SELECT category_id,uppercats,commentable,global_rank
+			  FROM '.IMAGE_CATEGORY_TABLE.'
+				INNER JOIN '.CATEGORIES_TABLE.' ON category_id = id
+			  WHERE image_id = '.$page['image_id'].'
+			  ;';
+//	               echo $query;
+			$result = pwg_query($query);
+			$related_categories = array();
+			while ($row = mysql_fetch_array($result))
+			{
+			  array_push($related_categories, $row['category_id']);
+			}
+			//
+            //echo related_categories;
+            if (count($related_categories))
+            {
+                // Request for all concours prepared & actived on each categories
+                $query = '
+                    SELECT *
+                    FROM ' . CONCOURS_TABLE .' 
+                    WHERE category IN ('.implode(',', $related_categories).')
+                    AND time_to_sec(TIMEDIFF(now(), end_date)) < 0
+                ';
+        //                echo $query;
+                $result = pwg_query($query);
+                // If one or more concours are found, the author name is masked 
+                if ($result && mysql_fetch_assoc($result))
+                {
                     $template->assign('INFO_AUTHOR',l10n('concours_img_author'));
+                }
             }
 		}
@@ -825,4 +880,5 @@
 
 
+    
 		if (($page['section']) == 'categories' AND !empty($page['category']))
 		{
@@ -1282,6 +1338,6 @@
 		$file = "rang, id_concours,method, img_id, img_name, img_file, date, note, moyenne, nbvotant, datas\r\n";
 
-		if (!(isset($this->concours_info['method'])))
-			$this->concours_info['method'] = 1;
+		if (!(isset($this->concours_infos['method'])))
+			$this->concours_infos['method'] = 1;
 			
 		// recover all img_id from the category
@@ -1292,7 +1348,7 @@
 		.' WHERE id_concours = '.($concours_id !== null ? $concours_id : $this->concours_id );
 		
-		if ($this->concours_info['method'] == 1)	// total
+		if ($this->concours_infos['method'] == 1)	// total
 			$query .= ' ORDER BY note DESC';
-		elseif ($this->concours_info['method'] == 2)	// moyenne
+		elseif ($this->concours_infos['method'] == 2)	// moyenne
 			$query .= ' ORDER BY moyenne DESC';
 		
@@ -1406,6 +1462,6 @@
 */		
 		// recover all img_id from the category
-		if (!(isset($this->concours_info['method'])))
-			$this->concours_info['method'] = 1;
+		if (!(isset($this->concours_infos['method'])))
+			$this->concours_infos['method'] = 1;
 		$query = 'SELECT id_concours, method, img_id, IMG.name, IMG.file, IMG.author, date, note, moyenne, nbvotant, datas, comment'
 		.' FROM ' .CONCOURS_RESULT_TABLE
@@ -1414,7 +1470,7 @@
 		.' WHERE id_concours = '.($concours_id !== null ? $concours_id : $this->concours_id );
 		
-		if ($this->concours_info['method'] == 1)	// total
+		if ($this->concours_infos['method'] == 1)	// total
 			$query .= ' ORDER BY note DESC';
-		elseif ($this->concours_info['method'] == 2)	// moyenne
+		elseif ($this->concours_infos['method'] == 2)	// moyenne
 			$query .= ' ORDER BY moyenne DESC';
 		
@@ -1447,9 +1503,12 @@
 			foreach ($user_list as $uuser)
 			{
-				
+
+				$comment = $this->get_img_comment_user($row['img_id'], $concours_id, $uuser['user_id']);
+			
 				$user_note = $this->get_img_note_user($row['img_id'], $concours_id, $uuser['user_id']);
 				
 				$file .= ', '.$uuser['username'].', '.$this->get_img_globalnote_user($row['img_id'], $concours_id, $uuser['user_id'])
-						.', '.($row['comment'] != null ? str_replace(",", "",$row['comment']) : '')
+//						.', '.($row['comment'] != null ? str_replace(",", "",$row['comment']) : '')
+						.', '.($comment != false ? str_replace(array(",","\r\n", "\n", "\r"), " ",$comment) : '')
 						.', '
 						;
@@ -816,7 +796,82 @@
         //                echo $query;
                 $result = pwg_query($query);
-                // If one or more concours are found, the author name is masked
+                // If one or more concours are found, the exifs are masked 
                 if ($result && mysql_fetch_assoc($result))